@@ -28,9 +28,9 @@ def send_answer(question_number,answer):
     else:
         _ran_x_times.append(question_number)
         if (len(answer) < 200):
-            print(f"Sending answer for question {question_number} to the server: \"" + answer + "\" ...")
+            print(f"Sending answer for question {question_number}: \"" + answer + "\" ...")
         else:
-            print(f"Sending the (very long) answer for question {question_number} to the server...")
+            print(f"Sending the (very long) answer for question {question_number}...")
         j = json.dumps({
             "q": question_number,
             "answer": answer
